/// <reference path='fourslash.ts' />

////var obj;
////for (var /**/p in obj) { }

goTo.marker();

verify.quickInfoIs('var p: any', "");
